#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: __init__.py 10670 2017-12-23 06:15:34Z David $
#
# Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: David $
# $Date: 2017-12-23 14:15:34 +0800 (Sat, 23 Dec 2017) $
# $Revision: 10670 $

from django.conf.urls import url, patterns

from Theophrastus.newsletter_extension import views

urlpatterns = patterns('',
    url(r'^newsletter/header/text/$', views.getDefaultHeaderText,
        name='Theophrastus.views.getDefaultHeaderText'),
    url(r'^newsletter/footer/text/$', views.getDefaultFooterText,
        name='Theophrastus.views.getDefaultFooterText'),
)
